SQLAlchemy 0.3 Documentation - module sqlalchemy.databases.firebird

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.10 Last Updated: 07/20/07 17:20:04

### module sqlalchemy.databases.firebird

### Module Functions

def descriptor()

### class FBBinary(Binary)

def get_col_spec(self)
back to section top

### class FBBoolean(Boolean)

def get_col_spec(self)
back to section top

### class FBChar(CHAR)

def get_col_spec(self)
back to section top

### class FBCompiler(ANSICompiler)

Firebird specific idiosincrasies

def limit_clause(self, select)

Already taken care of in the visit_select_precolumns method.

def visit_alias(self, alias)
def visit_function(self, func)
def visit_insert_column(self, column, parameters)
def visit_select_precolumns(self, select)

Called when building a `SELECT` statement, position is just before column list Firebird puts the limit and offset right after the `SELECT`...

back to section top

### class FBDate(DateTime)

def get_col_spec(self)
back to section top

### class FBDateTime(DateTime)

def get_col_spec(self)
back to section top

### class FBDefaultRunner(ANSIDefaultRunner)

def exec_default_sql(self, default)
def visit_sequence(self, seq)
back to section top

### class FBDialect(ANSIDialect)

def __init__(self, type_conv=200, concurrency_level=1, **kwargs)
def compiler(self, statement, bindparams, **kwargs)
def create_connect_args(self, url)
def create_execution_context(self, *args, **kwargs)
def dbapi(cls)
def defaultrunner(self, connection)
def do_commit(self, connection)
def do_execute(self, cursor, statement, parameters, **kwargs)
def do_rollback(self, connection)
def has_table(self, connection, table_name, schema=None)
def is_disconnect(self, e)
def max_identifier_length(self)
def preparer(self)
def reflecttable(self, connection, table)
def schemadropper(self, *args, **kwargs)
def schemagenerator(self, *args, **kwargs)
def supports_sane_rowcount(self)
def type_descriptor(self, typeobj)
back to section top

### class FBExecutionContext(DefaultExecutionContext)

def supports_sane_rowcount(self)
back to section top

### class FBIdentifierPreparer(ANSIIdentifierPreparer)

def __init__(self, dialect)
back to section top

### class FBInteger(Integer)

def get_col_spec(self)
back to section top

### class FBNumeric(Numeric)

def get_col_spec(self)
back to section top

### class FBSchemaDropper(ANSISchemaDropper)

def visit_sequence(self, sequence)
back to section top

### class FBSchemaGenerator(ANSISchemaGenerator)

def get_column_specification(self, column, **kwargs)
def visit_sequence(self, sequence)
back to section top

### class FBSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class FBString(String)

def get_col_spec(self)
back to section top

### class FBText(TEXT)

def get_col_spec(self)
back to section top